package io.zipcoder.casino;

public class HighLow extends DiceGame{
    private Player player;
    private boolean isPlaying = true;
    private int rolledDiceResult;
    private int totalBet;
    private String betCondition;
    private int winnings;

    public HighLow(Player player) {
        this.player = player;
    }

    private int askForWager() {
        int wager = 0;
        String input;
        Console.output("Current bankroll: " + this.player.getBankroll());
        boolean state = true;
        do {
            input = Console.askForInput("How much would you like to bet?");
            if (checkIfInteger(input) && checkBankroll(Integer.parseInt(input))) {
                wager = Console.numberFromString(input);
                state = false;
            }
        } while (state);
        bet(wager);
        return wager;
    }

    public boolean checkBankroll(int wager) {
        boolean state;
        if (wager <= 0 || wager > this.player.getBankroll()) {
            Console.output("Wrong input! Try again!");
            state = false;
        } else {
            state = true;
        }
        return state;
    }

    public boolean checkIfInteger(String input) {
        boolean state;
        if (!input.matches("\\d+")) {
            Console.output("Wrong input! Try again!");
            state = false;
        } else {
            state = true;
        }
        return state;
    }

    public void bet(int bet) {
            this.player.subtractFromBankroll(bet);
    }

    public String checkInput(String input, String[] values) {
        for (String currentValue : values) {
            if (currentValue.toLowerCase().equals(input.toLowerCase())) {
                return currentValue.toLowerCase();
            }
        }
        Console.output("Wrong input. Please try again");
        return null;
    }

    public void makeBet() {
        do {
            String input = Console.askForInput("What are you betting on?  (H / L / 7)");
            String[] values = {"h", "l", "7"};
            betCondition = checkInput(input, values);
        } while (betCondition == null);
    }

    public int rollDice() {
        Dice dice = new Dice(2);
        rolledDiceResult = dice.getSum();
        Console.output("You rolled " + rolledDiceResult);
        return rolledDiceResult;
    }

    public void declareWinner() {
        if ((betCondition.toUpperCase().equals("H") && rolledDiceResult >  7) ||
                (betCondition.toUpperCase().equals("L") && rolledDiceResult <  7) ||
                (betCondition.toUpperCase().equals("7") && rolledDiceResult == 7)) {
            winnings = rolledDiceResult == 7 ? this.totalBet * 4 : this.totalBet * 2;
            winBet(winnings);
        } else {
            loseBet(winnings);
        }
    }

    public boolean askToContinue() {
        if (!checkBankrupt()) {
            return false;
        }
        String input;
        do {
            input = Console.askForInput("Would you like to continue?  (Y / N)");
            String[] values = {"Y", "N"};
            input = checkInput(input, values);
        } while (input == null);
        return input.equals("y");
    }

    public boolean checkBankrupt() {
        if (this.player.getBankroll() == 0) {
            Console.output("You're bankrupt! Please come back after pay day!");
            return false;
        }
        return true;
    }

    public void winBet(int winnings) {
        player.addToBankroll(winnings);
        Console.output("You won " + winnings);
    }

    public void loseBet(int bet) {
        Console.output("You lost :(");
    }

    public void startGame() {
        Console.output("You're playing High-Low dice game");
        while (isPlaying) {
            totalBet         = askForWager();
            makeBet();
            rolledDiceResult = rollDice();
            declareWinner();
            isPlaying        = askToContinue();
        }
       // endGame();
    }

    public void endGame() {
        //???
    }

    public static void main (String[] args) {
        Player player = new Player("Francis");
        DiceGame app = new HighLow(player);
        app.startGame();
    }
}